@@ -125,7 +125,7 @@ static int PylibMC_Client_init(PylibMC_Client *self, PyObject *args,
 
 static PyObject *_PylibMC_parse_memcached_value(char *value, size_t size,
         uint32_t flags) {
-    PyObject *retval;
+    PyObject *retval, *tmp;
 
     retval = NULL;
     switch (flags) {
@@ -137,8 +137,11 @@ static PyObject *_PylibMC_parse_memcached_value(char *value, size_t size,
             retval = PyInt_FromString(value, NULL, 10);
             break;
         case PYLIBMC_FLAG_BOOL:
-            retval = PyInt_FromString(value, NULL, 10);
-            retval = PyBool_FromLong(PyInt_AS_LONG(retval));
+            if ((tmp = PyInt_FromString(value, NULL, 10)) == NULL) {
+                return NULL;
+            }
+            retval = PyBool_FromLong(PyInt_AS_LONG(tmp));
+            Py_DECREF(tmp);
             break;
         case PYLIBMC_FLAG_NONE:
             retval = PyString_FromStringAndSize(value, (Py_ssize_t)size);
@@ -660,10 +663,12 @@ static PyObject *PylibMC_Client_get_behaviors(PylibMC_Client *self) {
     PylibMC_Behavior *b;
 
     for (b = PylibMC_behaviors; b->name != NULL; b++) {
-        uint64_t bval = memcached_behavior_get(self->mc, b->flag);
-        PyObject *x = PyInt_FromLong(bval);
+        uint64_t bval;
+        PyObject *x;
 
-        if (x == NULL || PyDict_SetItemString(retval, b->name, x)) {
+        bval = memcached_behavior_get(self->mc, b->flag);
+        x = PyInt_FromLong((long)bval);
+        if (x == NULL || PyDict_SetItemString(retval, b->name, x) == -1) {
             goto error;
         }
 
@@ -681,23 +686,29 @@ static PyObject *PylibMC_Client_set_behaviors(PylibMC_Client *self,
     PylibMC_Behavior *b;
 
     for (b = PylibMC_behaviors; b->name != NULL; b++) {
-        if (PyMapping_HasKeyString(behaviors, b->name)) {
-            PyObject *v = PyMapping_GetItemString(behaviors, b->name);
-            memcached_return r;
+        PyObject *v;
+        memcached_return r;
 
-            if (!PyInt_Check(v)) {
-                PyErr_Format(PyExc_TypeError, "behavior %s must be int",
-                             b->name);
-                goto error;
-            }
+        if (!PyMapping_HasKeyString(behaviors, b->name)) {
+            continue;
+        }
 
-            r = memcached_behavior_set(self->mc, b->flag, PyInt_AS_LONG(v));
-            Py_DECREF(v);
-            if (r != MEMCACHED_SUCCESS) {
-                PyErr_Format(PylibMCExc_MemcachedError,
-                             "memcached_behavior_set returned %d", r);
-                goto error;
-            }
+        v = PyMapping_GetItemString(behaviors, b->name);
+
+        if (v == NULL) {
+            goto error;
+        } else if (!PyInt_Check(v)) {
+            PyErr_Format(PyExc_TypeError, "behavior %s must be int",
+                         b->name);
+            goto error;
+        }
+
+        r = memcached_behavior_set(self->mc, b->flag, (uint64_t)PyInt_AS_LONG(v));
+        Py_DECREF(v);
+        if (r != MEMCACHED_SUCCESS) {
+            PyErr_Format(PylibMCExc_MemcachedError,
+                         "memcached_behavior_set returned %d", r);
+            goto error;
         }
     }
 
@@ -793,8 +804,7 @@ static PyObject *_PylibMC_Pickle(PyObject *val) {
     retval = NULL;
     pickle_dump = _PylibMC_GetPickles("dumps");
     if (pickle_dump != NULL) {
-        retval = PyObject_CallFunctionObjArgs(pickle_dump, val,
-                                              PyInt_FromLong(-1), NULL);
+        retval = PyObject_CallFunction(pickle_dump, "Oi", val, -1);
         Py_DECREF(pickle_dump);
     }
 
